% LAMPF Matrix-free negative Laplacian.
% lapu=LAPMF(U) is the five-point Laplacian of U.
%
function lapu=lapmf(u)
n2=length(u);
n=sqrt(n2);
h2=(n+1)*(n+1);
%
% transform the linear array into a 2d array
%
uu=zeros(n,n);
uu(:)=u;
%
% compute the discrete negative Laplacian on the 2d array
%
lapuu=4*uu;
if n>1
lapuu(1:n-1,:)=lapuu(1:n-1,:)-uu(2:n,:);
lapuu(2:n,:)=lapuu(2:n,:)-uu(1:n-1,:);
lapuu(:,2:n)=lapuu(:,2:n)-uu(:,1:n-1);
lapuu(:,1:n-1)=lapuu(:,1:n-1)-uu(:,2:n);
end
%
% convert to a linear array, divide by h^2
%
lapu=lapuu(:)*h2;
